@@ -18,10 +18,12 @@ pub async fn log_in(user: &mut GooseUser) -> GooseTaskResult {
         Err(_) => "P@ssw0rd1234".to_string(),
     };
 
-    let login = goose_eggs::drupal::Login::username_password(&admin_username, &admin_password)
-        .unwrap()
-        .update_url("en/user/login");
-    goose_eggs::drupal::log_in(user, login.as_ref()).await?;
+    let login = goose_eggs::drupal::Login::builder()
+        .username(&*admin_username)
+        .password(&*admin_password)
+        .url("en/user/login")
+        .build();
+    goose_eggs::drupal::log_in(user, &login).await?;
 
     Ok(())
 }
@@ -35,10 +37,10 @@ pub async fn edit_article(user: &mut GooseUser) -> GooseTaskResult {
     goose_eggs::validate_and_load_static_assets(
         user,
         goose,
-        &goose_eggs::Validate::title_text(
-            article.unwrap().title_en,
-            &format!("en/node/{}/edit", article.unwrap().nid),
-        ),
+        &goose_eggs::Validate::builder()
+            .title(article.unwrap().title_en)
+            .text(&format!("en/node/{}/edit", article.unwrap().nid))
+            .build(),
     )
     .await?;
 
@@ -50,7 +52,9 @@ pub async fn edit_article(user: &mut GooseUser) -> GooseTaskResult {
     let edit_page = goose_eggs::validate_and_load_static_assets(
         user,
         goose,
-        &goose_eggs::Validate::title("Edit Article"),
+        &goose_eggs::Validate::builder()
+            .title("Edit Article")
+            .build(),
     )
     .await?;
 
@@ -83,7 +87,9 @@ pub async fn edit_article(user: &mut GooseUser) -> GooseTaskResult {
     goose_eggs::validate_and_load_static_assets(
         user,
         saved_article,
-        &goose_eggs::Validate::title(article.unwrap().title_en),
+        &goose_eggs::Validate::builder()
+            .title(article.unwrap().title_en)
+            .build(),
     )
     .await?;
 
